pub struct AppliedDirCreation<SrcSyncInfo, DstSyncInfo> { /* private fields */ }Expand description
Represent a DirCreation update that has been successfully applied on the FSBackend.
Implementations
Sourceimpl<SrcSyncInfo, DstSyncInfo> AppliedDirCreation<SrcSyncInfo, DstSyncInfo>
impl<SrcSyncInfo, DstSyncInfo> AppliedDirCreation<SrcSyncInfo, DstSyncInfo>
Sourcepub fn new(
parent_path: &VirtualPath,
src_dir: DirTree<SrcSyncInfo>,
dst_dir: DirTree<DstSyncInfo>,
) -> Self
pub fn new( parent_path: &VirtualPath, src_dir: DirTree<SrcSyncInfo>, dst_dir: DirTree<DstSyncInfo>, ) -> Self
Create a new AppliedDirCreation.
parent_path is the path to the parent of the created dir. Since an update cannot create a
root dir, it always exist.