Struct VirtualPath

pub struct VirtualPath { /* private fields */ }
A wrapper type that allows doing path operations on strings, without considerations for any concrete file system. These paths are supposed to be absolute and should start with a ‘/’.

Implementations

Source

impl VirtualPath

pub const fn root() -> &'static Self

Return the root path: “/”

pub fn is_root(&self) -> bool

Check if this path represent a “root”

pub fn len(&self) -> usize

Return the number of elements in the path

pub fn is_empty(&self) -> bool

alias for Self::is_root

pub fn chroot(&self, new_root: &VirtualPath) -> Result<&Self, VirtualPathError>

Return a new VirtualPath with a new root

pub fn is_inside(&self, other: &VirtualPath) -> bool

Return true if the node pointed by “self” is contained in “other”, eventually recursively Return also true if self == other

pub fn name(&self) -> &str

Return the name of the element pointed by this path

pub fn parent(&self) -> Option<&Self>

Return the parent of this path, if any

pub fn top_level(&self) -> Option<&str>

Return the top level directory of this path, for example “a” in “/a/b/c”. Return None is the provided path is the root

pub fn top_level_split(&self) -> Option<(&str, &Self)>

Return the path split in two components, the top level and the rest. For example, the path “a/b/c” will return Some(“a”, “/b/c”). Return None when called on a root path.

pub fn iter(&self) -> VirtualPathIterator<'_>

Return an iterator over the components of the path