pub struct VirtualPath { /* private fields */ }Expand description
A wrapper type that allows doing path operations on strings, without considerations for any concrete file system. These paths are supposed to be absolute and should start with a ‘/’.
Implementations
Sourceimpl VirtualPath
impl VirtualPath
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
alias for Self::is_root
Sourcepub fn chroot(&self, new_root: &VirtualPath) -> Result<&Self, VirtualPathError>
pub fn chroot(&self, new_root: &VirtualPath) -> Result<&Self, VirtualPathError>
Return a new VirtualPath with a new root
Sourcepub fn is_inside(&self, other: &VirtualPath) -> bool
pub fn is_inside(&self, other: &VirtualPath) -> bool
Return true if the node pointed by “self” is contained in “other”, eventually recursively Return also true if self == other
Sourcepub fn top_level(&self) -> Option<&str>
pub fn top_level(&self) -> Option<&str>
Return the top level directory of this path, for example “a” in “/a/b/c”. Return None is
the provided path is the root
Sourcepub fn top_level_split(&self) -> Option<(&str, &Self)>
pub fn top_level_split(&self) -> Option<(&str, &Self)>
Return the path split in two components, the top level and the rest. For example, the path “a/b/c” will return Some(“a”, “/b/c”). Return None when called on a root path.
Sourcepub fn iter(&self) -> VirtualPathIterator<'_> ⓘ
pub fn iter(&self) -> VirtualPathIterator<'_> ⓘ
Return an iterator over the components of the path